Export all spatial datasets in a database as geopackages.
Arguments
- conn
A SQLiteConnection to a database.
- dir
A string of the path to the directory to save the geopackages in.
- overwrite
A flag specifying whether to overwrite existing geopackages.
Export all spatial datasets in a database as geopackages.
A SQLiteConnection to a database.
A string of the path to the directory to save the geopackages in.
A flag specifying whether to overwrite existing geopackages.